@@ -4,7 +4,7 @@
 ;; Author: J.D. Smith <jdtsmith+elpa@gmail.com>
 ;; Homepage: https://github.com/jdtsmith/indent-bars
 ;; Package-Requires: ((emacs "27.1") (compat "30"))
-;; Version: 0.9
+;; Version: 0.9.1
 ;; Keywords: convenience
 
 ;; indent-bars is free software: you can redistribute it and/or
@@ -658,7 +658,7 @@ instead of the :blend factor in `indent-bars-color'."
 If BLEND-OVERRIDE is set, the main color's :blend will be ignored
 and this value will be used instead, for blending into the frame
 background color.  See `indent-bars-color-by-depth'."
-  (when-let ((cbd (indent-bars--style style "color-by-depth")))
+  (when-let* ((cbd (indent-bars--style style "color-by-depth")))
     (cl-destructuring-bind (&key regexp face-bg palette blend) cbd
       (let ((colors
 	     (cond
@@ -678,7 +678,7 @@ background color.  See `indent-bars-color-by-depth'."
 A color or palette (vector) of colors is returned, which may be
 nil, in which case no special current depth-coloring is used.
 See `indent-bars-highlight-current-depth' for configuration."
-  (when-let ((hcd (indent-bars--style style "highlight-current-depth")))
+  (when-let* ((hcd (indent-bars--style style "highlight-current-depth")))
     (cl-destructuring-bind (&key color face face-bg
 				 blend palette &allow-other-keys)
 	hcd
@@ -698,7 +698,8 @@ See `indent-bars-highlight-current-depth' for configuration."
 	  (if (string= color "unspecified-fg")
 	      (setq color indent-bars-unspecified-fg-color))
 	  (if blend
-	      (if-let ((palette (indent-bars--depth-palette style))) ; blend into normal depth palette
+	      (if-let* ((palette (indent-bars--depth-palette style)))
+		  ;; blend into normal depth palette
 		  (vconcat
 		   (mapcar (lambda (c)
 			     (indent-bars--blend-colors color c blend))
@@ -733,8 +734,9 @@ both variable pitch and fixed pitch fonts."
   (let ((win (or win (selected-window))))
     (with-selected-window win
       (or (when-let* ((ff (face-font 'default))
-		      (fi (font-info ff)))
-	    (aref fi 10))
+		      (fi (font-info ff))
+		      (space-width (aref fi 10)))
+	    (and (natnump space-width) (> space-width 0) space-width))
 	  (window-font-width)))))
 
 (defun indent-bars--stipple-face-spec (w h rot &optional style stipple)
@@ -829,7 +831,7 @@ Additional `defcustom` keyword arguments can be given as R."
 			 type))
 		       (t (setq type `(choice ,type))))))
     ;; Add an unspecified choice
-    (when-let ((tag-pos (member :tag choice)))
+    (when-let* ((tag-pos (member :tag choice)))
       (setq choice (cdr tag-pos)))	;after tag
     (setcdr choice
 	    (push
@@ -951,7 +953,7 @@ Useful for calling after theme changes."
   ;; Current depth highlight faces/stipple
   (setf (ibs/current-bg-color style)
 	(indent-bars--current-bg-color style))
-  (when-let ((stipple (indent-bars--current-depth-stipple nil nil nil style)))
+  (when-let* ((stipple (indent-bars--current-depth-stipple nil nil nil style)))
     (setf (ibs/current-stipple-face style)
 	  (indent-bars--tag "indent-bars%s-current-face" style))
     (face-spec-set (ibs/current-stipple-face style) nil)))
@@ -1016,7 +1018,7 @@ and can return an updated depth."
 	(forward-line 0)
 	(let* ((ppss (syntax-ppss))	; moves point!
 	       (string-start (and indent-bars-no-descend-string (nth 8 ppss)))
-	       (list-start (when-let
+	       (list-start (when-let*
 			       ((ndl indent-bars-no-descend-lists)
 				(open (nth 1 ppss))
 				((or (not (consp ndl)) (memq (char-after open) ndl))))
@@ -1283,8 +1285,7 @@ used to change the current depth highlight (aside from stipple changes).")
 
 (defun indent-bars--current-bg-color (style)
   "Return the current bar background color appropriate for STYLE."
-  (when-let ((hcd
-	      (indent-bars--style style "highlight-current-depth")))
+  (when-let* ((hcd (indent-bars--style style "highlight-current-depth")))
     (plist-get hcd :background)))
 
 (defun indent-bars--current-depth-stipple (&optional w h rot style)
@@ -1306,7 +1307,7 @@ Works by remapping the appropriate indent-bars[-tag]-N face for
 all styles in the `indent-bars--styles' list.  DEPTH should be
 greater than or equal to zero (zero meaning: no highlight)."
   (dolist (s indent-bars--styles)
-    (when-let ((c (alist-get (ibs/tag s) indent-bars--remaps))) ; out with the old
+    (when-let* ((c (alist-get (ibs/tag s) indent-bars--remaps))) ; out with the old
       (face-remap-remove-relative c))
     (when (> depth 0)
       (let* ((face (indent-bars--face s depth))
@@ -1561,22 +1562,22 @@ WIN defaults to the selected window.  To be set as a local
 	 (cur-whr (window-parameter win 'indent-bars-whr)))
     (unless (eq cur-whr whr)
       (set-window-parameter win 'indent-bars-whr whr))
-    (when-let ((buf (window-buffer win))
-	       (ht (buffer-local-value 'indent-bars--stipple-remaps buf))
-	       ((null (gethash whr ht))))
+    (when-let* ((buf (window-buffer win))
+		(ht (buffer-local-value 'indent-bars--stipple-remaps buf))
+		((null (gethash whr ht))))
       (with-current-buffer buf ; we may be called from an arbitrary buffer
 	(indent-bars--create-stipple-remaps w h rot)
 	(indent-bars--schedule-remap-cleanup)))))
 
 (defun indent-bars--cleanup-stipple-remaps (buf)
   "Clean up unused stipple face remaps for buffer BUF."
-  (when-let (((buffer-live-p buf))
-	     (wins (get-buffer-window-list buf nil t))
-	     (whrs (cl-loop for win in wins
-			    collect (window-parameter win 'indent-bars-whr)))
-	     (rmp-hsh (buffer-local-value 'indent-bars--stipple-remaps buf))
-	     (rkeys (hash-table-keys rmp-hsh))
-	     (unneeded (seq-difference rkeys whrs)))
+  (when-let* (((buffer-live-p buf))
+	      (wins (get-buffer-window-list buf nil t))
+	      (whrs (cl-loop for win in wins
+			     collect (window-parameter win 'indent-bars-whr)))
+	      (rmp-hsh (buffer-local-value 'indent-bars--stipple-remaps buf))
+	      (rkeys (hash-table-keys rmp-hsh))
+	      (unneeded (seq-difference rkeys whrs)))
     (with-current-buffer buf ;N.B. face-remapping-alist is buffer-local
       (dolist (rk unneeded)
 	(indent-bars--remove-plist-remaps (gethash rk rmp-hsh))
